/*
 *  Copyright 2010 Jesse Long.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package net.rumati.sqlblocks;

import net.rumati.sqlblocks.compile.ResultBuilder;

/**
 * Represents a list of {@link WhereCondition}s, where all conditions must be met.
 * @author jesse
 */
public class AndWhereConditionList
    extends WhereConditionList
{
    /**
     * Creates a new, empty AndWhereConditionList. This constructor allows for extending.
     */
    public AndWhereConditionList()
    {
    }

    /**
     * {@inheritDoc}
     */
    @Override
    final void compile(BaseSQLCompiler compiler, ResultBuilder result)
    {
        compiler.appendAndWhereConditionListSQL(this, result);
    }

    /**
     * Adds a condition to the list.
     * @param c The condition to add to the list.
     * @return This {@link AndWhereConditionList}
     */
    @Override
    public AndWhereConditionList addCondition(WhereCondition c)
    {
        super.addCondition(c);
        return this;
    }
}
