/*
 *  Copyright 2010 Jesse Long.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package net.rumati.sqlblocks;

import net.rumati.sqlblocks.compile.ResultBuilder;

/**
 * Represents a reference to a column in a table.
 * @author Jesse Long
 */
public class ColumnExpression
    extends Expression
{
    /**
     * The alias of the relation in which this column exists.
     */
    private final String relationAlias;
    /**
     * The name of the column
     */
    private final String columnName;

    /**
     * Creates a new {@link ColumnExpression}.
     * @param relationAlias The alias of the relation in which this column exists.
     * @param columnName The name of the column
     */
    public ColumnExpression(String relationAlias, String columnName)
    {
        this.relationAlias = relationAlias;
        this.columnName = columnName;
    }

    /**
     * Returns the column name.
     * @return The column name.
     */
    public String getColumnName()
    {
        return columnName;
    }

    /**
     * Returns the relation alias in which this column exists.
     * @return The relation alias in which this column exists.
     */
    public String getRelationAlias()
    {
        return relationAlias;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    final void compile(BaseSQLCompiler compiler, ResultBuilder result)
    {
        compiler.appendColumnExpressionSQL(this, result);
    }
}
