/*
 *  Copyright 2010 Jesse Long.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package net.rumati.sqlblocks;

import java.util.Collections;
import net.rumati.sqlblocks.compile.ResultBuilder;
import java.util.LinkedList;
import java.util.List;

public class SelectQuery
    extends Relation
{
    private final Relation from;
    private final String fromAlias;
    private final List<OutputColumn> outputColumns = new LinkedList<OutputColumn>();
    private final List<Join> joins = new LinkedList<Join>();
    private WhereCondition whereCondition = null;
    private int limit = 0;
    private int offset = 0;
    private final List<Expression> groupByColumns = new LinkedList<Expression>();
    private final List<OrderExpression> orderExpressions = new LinkedList<OrderExpression>();

    public SelectQuery(Relation from, String fromAlias)
    {
        this.from = from;
        this.fromAlias = fromAlias;
    }

    public void addOutputColumn(OutputColumn oc)
    {
        outputColumns.add(oc);
    }

    public void addOutputColumn(String tableAlias, String columnName, String alias)
    {
        addOutputColumn(new OutputColumn(new ColumnExpression(tableAlias, columnName), alias));
    }

    public List<OutputColumn> getOutputColumns()
    {
        return Collections.unmodifiableList(outputColumns);
    }

    public void addJoin(Join join)
    {
        joins.add(join);
    }

    public WhereCondition getWhereCondition()
    {
        return whereCondition;
    }

    public void setWhereCondition(WhereCondition whereCondition)
    {
        this.whereCondition = whereCondition;
    }

    public int getLimit()
    {
        return limit;
    }

    public int getOffset()
    {
        return offset;
    }

    public void setLimit(int limit)
    {
        this.limit = limit;
    }

    public void setOffset(int offset)
    {
        this.offset = offset;
    }

    public Relation getFrom()
    {
        return from;
    }

    public void addGroupByColumn(Expression column)
    {
        groupByColumns.add(column);
    }

    public void addGroupByColumn(String tableAlias, String columnName)
    {
        addGroupByColumn(new ColumnExpression(tableAlias, columnName));
    }

    public List<Expression> getGroupByColumns()
    {
        return Collections.unmodifiableList(groupByColumns);
    }

    public List<Join> getJoins()
    {
        return Collections.unmodifiableList(joins);
    }

    public void addOrderExpression(OrderExpression e)
    {
        orderExpressions.add(e);
    }

    public void addOrderExpression(Expression expression, OrderExpression.Direction direction)
    {
        orderExpressions.add(new OrderExpression(expression, direction));
    }

    public List<OrderExpression> getOrderExpressions()
    {
        return Collections.unmodifiableList(orderExpressions);
    }

    public String getFromAlias()
    {
        return fromAlias;
    }

    @Override
    void appendDefinition(BaseSQLCompiler compiler, ResultBuilder r)
    {
        compiler.appendSubQuerySQL(this, r);
    }
}
