/*
 *  Copyright 2010 Jesse Long.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package net.rumati.sqlblocks;

import net.rumati.sqlblocks.compile.ResultBuilder;

/**
 * Represents a condition used to filter results. Typically, for use in <code>WHERE</code> clauses in SQL,
 * and for <code>ON</code> clauses when joining tables. This class is abstract, each type of condition
 * is implemented in a seperate class in this package. This class may not be extended from outside of this package.
 * @author jesse
 */
public abstract class WhereCondition
{
    /**
     * Package private constructor to prevent inheritance by classes outside of this package.
     */
    WhereCondition(){}
    
    abstract void compile(BaseSQLCompiler compiler, ResultBuilder result);
}
