/*
 *  Copyright 2010 Jesse Long.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package net.rumati.sqlblocks.compile;

import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;

public class ResultBuilder
{
    private final StringBuilder stringBuilder = new StringBuilder();
    private final Map<String, Integer> parameterNumber = new TreeMap<String, Integer>();
    private final List<String> parameterNames = new LinkedList<String>();
    private int indentationLevel = 0;

    public ResultBuilder()
    {
    }

    public ResultBuilder indent()
    {
        this.indentationLevel++;
        return append("    ");
    }

    public ResultBuilder unindent()
    {
        this.indentationLevel--;
        return this;
    }

    public ResultBuilder addParameter(String key)
    {
        parameterNumber.put(key, parameterNumber.size() + 1);
        parameterNames.add(key);
        return this;
    }

    public ResultBuilder append(String str)
    {
        int idx = str.indexOf("\n");
        while (idx > -1){
            stringBuilder.append(str.substring(0, idx));
            str = str.substring(idx + 1);
            idx = str.indexOf("\n");
        }
        stringBuilder.append(str);
        return this;
    }
    
    public ResultBuilder append(char c)
    {
        if (c == '\n'){
            return appendNewLine();
        }
        stringBuilder.append(c);
        return this;
    }
    
    public ResultBuilder appendNewLine()
    {
        stringBuilder.append('\n');
        
        for (int i = 0; i < indentationLevel * 4; i++){
            stringBuilder.append(' ');
        }
        
        return this;
    }

    public Result getResult()
    {
        return new Result(stringBuilder.toString(), parameterNumber, parameterNames);
    }
}
